function p = engset(A,N,M)
%ENGSET Calculates probabilities using the Engset distribution
%Call [p,B] = engset(A,N,M)
%Where A = total offered traffic in Erlang, with no calls in progress
%      M = number of sources 
%      N = number of serving trunks
%Returns
%      p = vector of Engset probabilities for source states 0 ... N
%
A=A/M
p = (A.^(0:N)).*bincoeff(M,0:N)
p = p/sum(p)


